##############################################################################
#
# PhotoExt for Zope
#
# Copyright (c) Mark Gibson  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Mark Gibson      mngibso@excite.com
#
##########################################################################
# This product is inspired by and designed be used with Ron Bickers's Photo 
# product.  Many of the ideas and much of the code found herein is culled
# from the Photo product.  Many thanks to Ron for providing such a useful
# product.
#
# Ron Bickers Photo Product:
# http://www.zope.org/Members/rbickers/Photo
#
#
#############################################################################
"""PhotoExt

  PhotoExt requires the installation of Ron Bickers's Photo Product:
  http://www.zope.org/Members/rbickers/Photo

  PhotoExt extends the Photo Products funtcionality by allowing a user to 
  upload multiple photos through a single screen.
"""

from Globals import InitializeClass, DTMLFile
from Products.Photo.Photo import Photo
from Products.Photo.PhotoFolder import PhotoFolder
from OFS import SimpleItem
#from OFS.Image import cookId
from Products.Photo import Photo, manage_addPhoto
import sys

manage_addMultiPhotoForm = DTMLFile('dtml/addMultiPhotosForm', globals())
manage_confirmationForm = DTMLFile('dtml/confirmationForm', globals())

#Add confirmation form to the PhotoFolder
PhotoFolder.confirmationForm = manage_confirmationForm

class PhotoExt:
   """ PhotoExt"""
   meta_type = "Multiple Photos"

def manage_addMultiPhoto(dispatcher, id='', title='', file='',
                    content_type='', precondition='',
                    store='Image', engine='ImageMagick', quality=75,
                    timeout=0, pregen=0, REQUEST=None):

    """Add Photo object."""
    #Check to see if submit button was pressed, if not, user is just changing
    #the number of photos
    if REQUEST and not REQUEST.form.has_key('Add'):
       REQUEST.RESPONSE.redirect(REQUEST['from_url'] + '?number_photos=' + REQUEST['number_photos'] )
       return 

    success=[]
    fail=[]
    for photo_index in range(int(REQUEST['number_photos'])):
        photo=REQUEST[str(photo_index)]
        id=photo[0]
        title=photo[1]
        file=photo[2]
        if file and file.filename !='':
           try: 
              ret=manage_addPhoto(dispatcher,id,title,file,content_type,
                precondition, store,engine,quality,timeout,pregen,REQUEST=None)
              get_transaction().commit()
              success.append(file.filename)
           except:  
              fail.append( {'filename':file.filename,'errortype':sys.exc_type,
                           'errorvalue':sys.exc_value} )

    
    try: manage_confirmationForm=dispatcher.confirmationForm
    except: manage_confirmationForm=None

    if REQUEST is not None:
       try:    url=dispatcher.DestinationURL()
       except: url=REQUEST['URL1'] 

       #if manage_confirmationForm exists, use it
       if manage_confirmationForm:
          return manage_confirmationForm(dispatcher, REQUEST=REQUEST, 
                 fail=fail, success=success, return_url=url+ '/manage_main')
       else:
          if len(fail) > 0:
             #no confirmation form, so re-raise errors if they exist
             errortype=''
             errorvalue=''
             for error in fail:
                errortype=errortype+'<br />&nbsp;&nbsp;' + error['errortype']
                errorvalue=errorvalue+'<br />&nbsp;&nbsp;' + error['errorvalue']
             raise errortype, errorvalue
          REQUEST.RESPONSE.redirect(url + '/manage_main') 
    return None

InitializeClass(PhotoExt) 
